#      	Udita Brahmachari, Graduate Student
#		Loren Williams, Georgia Tech	
#      Script for analyzing structure of DNA bound NotI
#      PDB entry: 3C25
#      Reference: Structures of the rare-cutting restriction 
#      endonuclease NotI reveal a unique metal binding fold 
#      involved in DNA binding, Lambert, A.R., Sussman, D., 
#      Shen, B., Maunus, R.,  Nix, J., Samuelson, J., Xu, S.Y., 
#      Stoddard, B.L
#      Journal: Structure 16: 558-569

reinitialize
bg_color white

load NOTI_3c25.pdb, Complex



#---------remove resn HOH and Complex
create DNA, Complex and Chain C+D 
remove resn HOH and DNA


#---------cartoon DNA
create Cartoon_DNA, DNA
set cartoon_ring_mode=2, Cartoon_DNA
hide everything, Cartoon_DNA
set cartoon_tube_radius=0.4, Cartoon_DNA
show cartoon, Cartoon_DNA


#---------Stick DNA
create Stick_DNA, DNA
hide everything, Stick_DNA
show stick, Stick_DNA
color wheat, (Stick_DNA and name C*)
color red, (Stick_DNA and name O*)
color blue, (Stick_DNA and name N*)
color yelloworange, (Stick_DNA and name P)

#--------------- Watson-Crick hydrogen bonds----------------
distance WC_Hbond, (name O2,N3,N4 and resn DC and Stick_DNA ), (name N2,N1,O6 and resn DG and Stick_DNA ), 3.1
distance WC_Hbond, (name N3,O4 and resn DT and Stick_DNA ), (name N1,N6 and resn DA and Stick_DNA ), 3.1
color black, WC_Hbond
hide labels, WC_Hbond
set dash_width, 3
set dash_gap, 0.4

disable WC_Hbond




#-------- Cartoon Protein
create Cartoon_Protein, Complex and Chain A+B
hide everything, Cartoon_Protein
show cartoon, Cartoon_Protein
set cartoon_cylindrical_helices,2, Cartoon_protein
color blue, Cartoon_Protein
color cyan, ss h and Cartoon_Protein
color magenta, ss s and Cartoon_Protein



#--------Stick Protein 
create Stick_Protein, Complex and Chain A+B
hide everything, Stick_Protein
show stick, Stick_Protein
color bluewhite, name C* and Stick_Protein
color blue, name N* and Stick_Protein
color red, name O* and Stick_Protein
color yellow, name S* and Stick_Protein

disable Stick_Protein


#-------------Chain A (with Fe atom and different domains)
create Chain_A, chain A and Complex
hide everything, Chain_A
show cartoon, Chain_A
color blue, resi 1-85 and Chain_A
color green, resi 88-111 and Chain_A
color green, resi 118-138 and Chain_A
color green, resi 161-184 and Chain_A
color purple, resi 192-223 and Chain_A
color red, resi 231-250 and Chain_A
color green, resi 257-262 and Chain_A
color green, resi 298-324 and Chain_A
color cyan, resi 326-362 and Chain_A
show spheres, resn FE and Chain_A

disable Chain_A

#--------------Chain B
create Chain_B, chain b and Complex
hide everything, Chain_B
show cartoon, Chain_B
color gray, Chain_B
show spheres, resn FE and Chain_B

disable Chain_B

#--------------Metal binding domain (Fe)
create Fe_complex, /Complex//A/CYS`42/* + /Complex//A/CYS`55/* + /Complex//A/CYS`65/* + /Complex//A/CYS`81/* + /Complex//A/FE`901/FE
hide everything, Metal_Complex_A
show stick, Fe_complex
show sphere, /Fe_complex//A/FE`901/FE
alter /Fe_complex//A/FE`901/FE, vdw=.6


#-----------DNA fragment
create DNA_fragment, resi 8-15 and Stick_DNA  
show cartoon, DNA_fragment


#-------------Active site
create Active_site, /Complex//*/CA`801/CA + /Complex//*/CA`802/CA + /Complex//*/CA`803/CA + /Complex//*/CA`804/CA + /Complex//*/GLN`184/* + /Complex//*/GLU`182/* + /Complex//*/ASP`160/* +  /Complex//*/GLU`145/* + /Stick_DNA//*/DG`10/* + /Stick_DNA//*/DC`9/* + /Complex//A/HOH`923/* + /Complex//B/HOH`918/* 
hide everything, Active_site
show stick, Active_site
show sphere, Active_site and resn HOH 
show sphere, Active_site and resn CA
alter Active_site and resn CA, vdw=0.6
alter Active_site and resn HOH, vdw=0.4
rebuild

distance Ca_coordination, (Active_site and name OE2 and resi 145*),(Active_site and name CA), 3.0
distance Ca_coordination, (Active_site and name OD1 and resi 160*),(Active_site and name CA), 2.9
distance Ca_coordination, (Active_site and name OD2 and resi 160*),(Active_site and name CA), 3.4
distance Ca_coordination, (Active_site and name OE2 and resi 182*),(Active_site and name CA), 3.0
distance Ca_coordination, (Active_site and name OE1 and resi 182*),(Active_site and name CA), 3.0

distance Ca_coordination, (Active_site and name O3' and resi 10*),(Active_site and name CA), 3.7
distance Ca_coordination, (Stick_DNA and name OP1 and resi 10*),(Active_site and name CA), 2.8


create nucleophile, Active_site and resn HOH
show spheres, nucleophile
alter nucleophile, vdw=0.5
rebuild

distance Ca_coordination, (Active_site and name NE2 and resi 184*),(nucleophile), 2.7
distance Ca_coordination, (Active_site and name CA),(nucleophile), 2.7
color black, Ca_coordination
set dash_width, 3
set dash_gap, 0.4

label nucleophile, "Nucleophilic Water"
set label_size, 14, nucleophile
set label_color, deepteal, nucleophile
set label_outline_color, black, nucleophile
set label_shadow_mode=2, nucleophile


#-----------DNA fragment
create DNA_fragment, resi 8-15 and Stick_DNA  
show cartoon, DNA_fragment


#-----------DNA contacts

#-----------G4--C4
create G_4C_4, /Complex//*/SER`158/* + /Complex//*/HIS`189/* + /DNA_fragment//*/DG`8/* + /DNA_fragment//*/DC`15/* +  /Complex//C/HOH`39/* +  /Complex//C/HOH`49/*
hide everything, G_4C_4
show sticks, G_4C_4
show sphere, G_4C_4 and resn HOH 
alter G_4C_4 and resn HOH, vdw=0.4
rebuild
distance G4__C4, (G_4C_4 and name ND1 and resi 189*),(G_4C_4 and name O6 and resi 8), 3.0
distance G4__C4, (G_4C_4 and name OG and resi 158*),(G_4C_4 and name O and resi 39), 3.3
distance G4__C4, (G_4C_4 and name N3 and resi 8),(G_4C_4 and name O and resi 39), 3.3

#-----------C3--G3
create G_3C_3,/Complex//*/ASN`230/* + /Complex//*/HIS`189/* + /Complex//*/GLY`190/* + /DNA_fragment//*/DG`14/* + /DNA_fragment//*/DC`9/*
hide everything, G_3C_3
show sticks, G_3C_3
distance G3__C3, (G_3C_3 and name ND1 and resi 189*),(G_3C_3 and name O6 and resi 14), 3.2
distance G3__C3, (G_3C_3 and name N and resi 190*),(G_3C_3 and name N7 and resi 14), 3.2
distance G3__C3, (G_3C_3 and name OD1 and resi 230*),(G_3C_3 and name N4 and resi 9), 3.0


#-----------G2--C2
create G_2C_2,/Complex//*/ASN`230/* + /Complex//*/ASN`233/* + /Complex//*/PHE`188/* + /DNA_fragment//*/DG`10/* + /DNA_fragment//*/DC`13/* + /Complex//A/HOH`924/* + /Complex//D/HOH`31/*
hide everything, G_2C_2
show sticks, G_2C_2
show sphere, G_2C_2 and resn HOH 
alter G_2C_2 and resn HOH, vdw=0.4
rebuild
distance G2__C2, (G_2C_2 and name O and resi 188*),(G_2C_2 and name N4 and resi 13), 3.2
distance G2__C2, (G_2C_2 and name ND2 and resi 230*),(G_2C_2 and name O6 and resi 10), 3.0
distance G2__C2, (G_2C_2 and name OD1 and resi 233*),(G_2C_2 and name O and resi 924), 2.8
distance G2__C2, (G_2C_2 and name N7 and resi 10),(G_2C_2 and name O and resi 924), 3.0
distance G2__C2, (G_2C_2 and name N7 and resi 10),(G_2C_2 and name O and resi 31), 3.1
distance G2__C2, (G_2C_2 and name OD1 and resi 233*),(G_2C_2 and name O and resi 31), 3.1

#--------G1--C1
create G_1C_1,/Complex//*/ASP`187/* + /Complex//*/ARG`237/* + /DNA_fragment//*/DG`11/* + /DNA_fragment//*/DC`12/*
hide everything, G_1C_1
show sticks, G_1C_1
distance G1__C1, (G_1C_1 and name NH1 and resi 237*),(G_1C_1 and name N7 and resi 11), 3.0
distance G1__C1, (G_1C_1 and name NH2 and resi 237*),(G_1C_1 and name O6 and resi 11), 3.0
distance G1__C1, (G_1C_1 and name NH2 and resi 237*),(G_1C_1 and name N7 and resi 11), 3.3
distance G1__C1, (G_1C_1 and name NH1 and resi 237*),(G_1C_1 and name O6 and resi 11), 3.4
distance G1__C1, (G_1C_1 and name OD2 and resi 187*),(G_1C_1 and name N4 and resi 12), 3.3


#------------Non-specific
create non-specific, DNA_fragment + /Complex//*/GLU`227/* + /Complex//*/THR`60/* + /Complex//*/SER`191/* + /Complex//*/LYS`57/* + /Complex//*/SER`61/* + /Complex//*/TYR`192/* + /Complex//*/THR`185/* + /Complex//*/GLN`241/* + /Complex//*/SER`232/* + /Complex//*/LYS`236/* + /Complex//*/LYS`245/* + /Complex//*/PHE`188/* + /Complex//A/HOH`925/* + /Complex//B/HOH`904/* + /Complex//B/HOH`903/* + /Complex//A/HOH`922/*  
hide everything, non-specific
show sticks, non-specific
show sphere, non-specific and resn HOH 
alter non-specific and resn HOH, vdw=0.4
rebuild
distance non-specific_HB, (non-specific and name OE2 and resi 227*),(non-specific and name O and resi 925), 3.3
distance non-specific_HB, (non-specific and name OP2 and resi 14),(non-specific and name O and resi 925*), 3.3
distance non-specific_HB, (non-specific and name OE2 and resi 227*),(non-specific and name O and resi 904), 3.3
distance non-specific_HB, (non-specific and name OP2 and resi 14),(non-specific and name O and resi 904*), 3.3
distance non-specific_HB, (non-specific and name OG and resi 232*),(non-specific and name O and resi 903*), 3.3
distance non-specific_HB, (non-specific and name OP2 and resi 9),(non-specific and name O and resi 903*), 3.3
distance non-specific_HB, (non-specific and name OG and resi 232*),(non-specific and name O and resi 922*), 3.3
distance non-specific_HB, (non-specific and name OP2 and resi 9*),(non-specific and name O and resi 922*), 3.3


distance non-specific_HB, (non-specific and name NZ and resi 245*),(Stick_DNA and name OP1 and resi 9), 3.3
distance non-specific_HB, (non-specific and name NZ and resi 236*),(Stick_DNA and name OP2 and resi 9), 3.3



distance non-specific_HB, (non-specific and name OG1 and resi 185*),(Stick_DNA and name OP1 and resi 11), 3.3
distance non-specific_HB, (non-specific and name OG1 and resi 60*),(Stick_DNA and name OP1 and resi 13), 3.3
distance non-specific_HB, (non-specific and name OG and resi 191*),(Stick_DNA and name OP2 and resi 13), 3.3
distance non-specific_HB, (non-specific and name OH and resi 192*),(Stick_DNA and name OP2 and resi 12), 3.3
distance non-specific_HB, (non-specific and name OG and resi 61*),(Stick_DNA and name OP1 and resi 12), 3.3
distance non-specific_HB, (non-specific and name NZ and resi 57*),(Stick_DNA and name OP1 and resi 12), 3.3
distance non-specific_HB, (non-specific and name NE2 and resi 241*),(Stick_DNA and name OP2 and resi 10), 3.3
distance non-specific_HB, (non-specific and name NE2 and resi 241*),(Stick_DNA and name OP2 and resi 10), 3.3

color black, G4__C4
color black, G3__C3
color black, G2__C2
color black, G1__C1
color black, non-specific_HB
set dash_width, 3
set dash_gap, 0.4


disable all
enable Cartoon_DNA
enable Stick_DNA
enable Cartoon_Protein



#-----------orient image
set_view (\
     0.977490366,   -0.157630891,   -0.140232459,\
    -0.109265245,    0.190361872,   -0.975614488,\
     0.180482045,    0.968977511,    0.168853089,\
     0.000000000,    0.000000000, -198.453796387,\
   -15.856418610,    1.356447220,  -18.163715363,\
   149.627487183,  247.280090332,    0.000000000 )
### cut above here and paste into script ### 

Raychem
